@@ -4,7 +4,8 @@ from flask import Blueprint, request, jsonify, abort
 from flask.views import MethodView
 from werkzeug.exceptions import BadRequest
 
-from home.ts.models import Device, Series, DataPoint, DeviceSeries
+from home.ts import graph
+from home.ts.models import Area, Device, Series, DataPoint, DeviceSeries
 
 api = Blueprint('Dashboard API', __name__)
 
@@ -48,16 +49,22 @@ def kwarg_json_query(f):
 
 class JSONResource(MethodView):
 
-    def jsonify_qs(self, qs, **kwargs):
+    def jsonify_qs(self, result_sets, **kwargs):
 
-        dicts = [i.as_dict() for i in qs]
+        r = []
 
-        return jsonify(results=dicts, count=len(dicts), **kwargs)
+        for result_set in result_sets:
+            r.append({
+                'values': [i.as_dict() for i in result_set],
+                'count': len(list(result_set)),
+            })
+
+        return jsonify(data=r, **kwargs)
 
 
 class Resource(JSONResource):
 
-    page_size = 100
+    page_size = 1000
 
     def get(self, resource_id=None, name=None):
 
@@ -77,7 +84,7 @@ class Resource(JSONResource):
             self.model.created_at.desc())
         offset = (page - 1) * self.page_size
         results = results.limit(self.page_size).offset(offset)
-        return self.jsonify_qs(results, page=page)
+        return self.jsonify_qs([results, ], page=page)
 
 
 class DevicesResource(Resource):
@@ -96,11 +103,16 @@ class ValuesResource(Resource):
     model = DataPoint
 
 
-class SearchResource(ValuesResource):
+class AreasResource(Resource):
+    model = Area
+
+
+class GraphResource(ValuesResource):
 
     @kwarg_json_query
     def post(self, query=None):
 
+        graph_func = None
         device_series_id = None
 
         if query is None:
@@ -115,6 +127,9 @@ class SearchResource(ValuesResource):
                 series_id=query['series_id'],
             ).first()
 
+            if 'graph' not in query:
+                graph_func = graph.get_method(ds.series.graph)
+
             if ds is not None:
                 device_series_id = ds.id
 
@@ -129,11 +144,19 @@ class SearchResource(ValuesResource):
             end = query['end']
             qs = qs.filter(DataPoint.created_at.between(start, end))
 
-        return self.jsonify_qs(qs.limit(10000))
+        qs = qs.limit(10000)
+
+        if graph_func is not None:
+            qs = graph_func(qs)
+        else:
+            qs = [qs, ]
+
+        return self.jsonify_qs(qs)
 
 
-register_api(DevicesResource, 'devices', '/devices/')
-register_api(SeriesResource, 'series', '/series/')
+register_api(AreasResource, 'areas', '/areas/')
 register_api(DeviceSeriesResource, 'device_series', '/device_series/')
+register_api(DevicesResource, 'devices', '/devices/')
+register_api(GraphResource, 'graph', '/graph/')
+register_api(SeriesResource, 'series', '/series/')
 register_api(ValuesResource, 'values', '/values/')
-register_api(SearchResource, 'search', '/search/')
