@@ -3,7 +3,7 @@ from collections import OrderedDict
 from sqlalchemy.sql import text
 from flask import render_template, Blueprint
 
-from home.ts.models import db, Device
+from home.ts.models import db, Area, Device, Series
 
 
 web = Blueprint('Dashboard Web', __name__)
@@ -11,30 +11,33 @@ web = Blueprint('Dashboard Web', __name__)
 
 @web.context_processor
 def inject_devices():
-    return dict(devices=Device.query.order_by(Device.name).all())
+    return dict(devices=Device.query.join(Area).order_by(Area.name).all())
 
 
 @web.route('/')
-@web.route('/device/<device_name>/')
+@web.route('/areas/<device_name>/')
 def dashboard(device_name=None):
 
+    series_map = {s.id: s for s in Series.query.all()}
+
     query = """ SELECT
-    device.id as device_id, device.name as device_name,
+    device.id as device_id, area.name as device_name,
     series.id as series_id, series.name as series_name,
     ARRAY (
         SELECT hstore(data_point)
         FROM data_point
         WHERE data_point.device_series_id = device_series.id
         ORDER BY data_point.created_at DESC
-        LIMIT 10
+        LIMIT 30
     ) as latest
     FROM device_series
     JOIN device ON device.id = device_series.device_id
-    JOIN series ON series.id = device_series.series_id"""
+    JOIN series ON series.id = device_series.series_id
+    JOIN area ON area.id = device.area_id"""
 
     if device_name:
         kwargs = {'device_name': device_name}
-        query += "\n    WHERE device.name = :device_name"
+        query += "\n    WHERE area.name = :device_name"
     else:
         kwargs = {}
 
@@ -50,6 +53,7 @@ def dashboard(device_name=None):
 
         structured[row.device_name].append({
             'series_id': row.series_id,
+            'model': series_map[row.series_id],
             'device_id': row.device_id,
             'name': row.series_name,
             'value': row.latest[0]['value'],
